[Libreoffice-commits] help.git: GeneratedPackage_html_media.mk help3xsl/convert2html.sh help3xsl/get_media.sh help3xsl/xhp2html.sh helpers/find-invalid-help-images.sh

Rene Engelhard rene at rene-engelhard.de
Sat May 5 13:27:15 UTC 2018


 GeneratedPackage_html_media.mk      |    2 +-
 help3xsl/convert2html.sh            |    2 +-
 help3xsl/get_media.sh               |    4 ++--
 help3xsl/xhp2html.sh                |    2 +-
 helpers/find-invalid-help-images.sh |    8 ++++----
 5 files changed, 9 insertions(+), 9 deletions(-)

New commits:
commit a154b3f59a7d6e6cf17e585521592bf96b42a20e
Author: Rene Engelhard <rene at rene-engelhard.de>
Date:   Sat May 5 15:13:01 2018 +0200

    s/galaxy/colibre/
    
    ... as galaxy got removed with 60413c9800c27f53c1108015b50754b065bc98c6
    
    Change-Id: I4e3ec6db6b57b31e184ec53def5bdb54e064ad21

diff --git a/GeneratedPackage_html_media.mk b/GeneratedPackage_html_media.mk
index 9e483738a..423e6a2df 100644
--- a/GeneratedPackage_html_media.mk
+++ b/GeneratedPackage_html_media.mk
@@ -9,7 +9,7 @@
 #
 $(eval $(call gb_GeneratedPackage_GeneratedPackage,helpcontent2_html_media,$(SRCDIR)))
 
-$(eval $(call gb_GeneratedPackage_add_dir,helpcontent2_html_media,$(INSTROOT)/$(LIBO_SHARE_HELP_FOLDER)$(if $(HELP_ONLINE),/$(PRODUCTVERSION))/media/icon-themes,icon-themes/galaxy))
+$(eval $(call gb_GeneratedPackage_add_dir,helpcontent2_html_media,$(INSTROOT)/$(LIBO_SHARE_HELP_FOLDER)$(if $(HELP_ONLINE),/$(PRODUCTVERSION))/media/icon-themes,icon-themes/colibre))
 
 $(eval $(call gb_GeneratedPackage_add_dir,helpcontent2_html_media,$(INSTROOT)/$(LIBO_SHARE_HELP_FOLDER)$(if $(HELP_ONLINE),/$(PRODUCTVERSION))/media/helpimg,helpcontent2/source/media/helpimg))
 $(eval $(call gb_GeneratedPackage_add_dir,helpcontent2_html_media,$(INSTROOT)/$(LIBO_SHARE_HELP_FOLDER)$(if $(HELP_ONLINE),/$(PRODUCTVERSION))/media/navigation,helpcontent2/source/media/navigation))
diff --git a/help3xsl/convert2html.sh b/help3xsl/convert2html.sh
index 3cfe860d9..f48f1d8a8 100755
--- a/help3xsl/convert2html.sh
+++ b/help3xsl/convert2html.sh
@@ -287,7 +287,7 @@ echo '</sitemapindex>'>>$sitemap
 cp normalize.css default.css help.js fuse.js paginathing.js $outDir
 cp -r $enSource/source/media $outDir
 mkdir -p $outDir/media/icon-themes
-#cp -a ../../icon-themes/galaxy/* $outDir/media/icon-themes/
+#cp -a ../../icon-themes/colibre/* $outDir/media/icon-themes/
 #ln -s $productversion html/latest
 
 exit
diff --git a/help3xsl/get_media.sh b/help3xsl/get_media.sh
index eaaeb44f1..ac1e90fc5 100755
--- a/help3xsl/get_media.sh
+++ b/help3xsl/get_media.sh
@@ -39,5 +39,5 @@ cp default.css $outDir'/'$productVersion'/'
 
 cp -a ../source/media $outDir'/'$productVersion'/'
 
-galaxy=$(realpath $workDir'/../icon-themes/galaxy')
-cp -a $galaxy $outDir'/'$productVersion'/media/icon-themes'
+colibre=$(realpath $workDir'/../icon-themes/colibre')
+cp -a $colibre $outDir'/'$productVersion'/media/icon-themes'
diff --git a/help3xsl/xhp2html.sh b/help3xsl/xhp2html.sh
index 6da95dbd9..f65f58a07 100755
--- a/help3xsl/xhp2html.sh
+++ b/help3xsl/xhp2html.sh
@@ -181,7 +181,7 @@ cp default.css $here'/html/'$productversion'/'
 
 cp -a ../source/media $here'/html/'$productversion'/'
 mkdir -p $here'/html/'$productversion'/media/icon-themes'
-cp -a ../../icon-themes/galaxy/* $here'/html/'$productversion'/media/icon-themes/'
+cp -a ../../icon-themes/colibre/* $here'/html/'$productversion'/media/icon-themes/'
 ln -s $productversion html/latest
 
 # Set helpex utility and environment
diff --git a/helpers/find-invalid-help-images.sh b/helpers/find-invalid-help-images.sh
index c73d40ed2..d779f80b8 100755
--- a/helpers/find-invalid-help-images.sh
+++ b/helpers/find-invalid-help-images.sh
@@ -6,7 +6,7 @@
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
 # This script looks up <image ...> tags in helpcontent, checks whether the
 # referenced file exist in the galaxy theme or in source/ and prints a warning if it does not.
 # Execute from the root directory of the helpcontent2 repository.
 # No parameters are used.
 
@@ -22,11 +22,11 @@ while read nextline ; do
     img3=${img2%%\"*};
 
     # Check the images existence
-    if [ ! -f "../icon-themes/galaxy/$img3" ] ; then
-        # Not present in galaxy, but it may be under source/
+    if [ ! -f "../icon-themes/colibre/$img3" ] ; then
+        # Not present in colibre, but it may be under source/
         if [ ! -f "source/$img3" ] ; then
             # Not even there, we have an error!
-            echo "$img3 included in file $sourcefile is not found in the galaxy theme or the help media!";
+            echo "$img3 included in file $sourcefile is not found in the colibre theme or the help media!";
         fi
      fi
 done <<< "$images"
@@ -6,7 +6,7 @@
 
 # This script looks up <image ...> tags in helpcontent, checks whether the
-# referenced file exist in the galaxy theme or in source/ and prints a warning if it does not.
+# referenced file exist in the colibre theme or in source/ and prints a warning if it does not.
 # Execute from the root directory of the helpcontent2 repository.
 # No parameters are used.


More information about the Libreoffice-commits mailing list